import { Component, OnInit, AfterViewInit, ViewChild, ChangeDetectionStrategy, ViewEncapsulation, ɵConsole } from '@angular/core';
//import { PageSettingsModel, EditService, RowSelectEventArgs } from '@syncfusion/ej2-angular-grids';
import { TreeGridComponent, PageSettingsModel, TreeGrid, Page, EditService, PageService, ToolbarService, SortService, FilterService, DataStateChangeEventArgs } from '@syncfusion/ej2-angular-treegrid';
import { SystemService } from '../../commissioning/services/system.service';
import { LoaderService } from '../../services/loader.service';
import { ToastrService } from '../../fm/services/toastr.service';
import { AuthenticationService } from '../../services/auth.service';
import { DataManager, Query, UrlAdaptor, WebApiAdaptor, WebMethodAdaptor, JsonAdaptor } from '@syncfusion/ej2-data';

import { Observable } from 'rxjs/Observable';
TreeGrid.Inject(Page);

@Component({
  selector: 'app-tags',
  templateUrl: './tags.component.html',
  styleUrls: ['./tags.component.scss'],
  providers: [EditService, PageService, SortService, ToolbarService, FilterService]

})
export class TagsComponent implements OnInit, AfterViewInit {

  @ViewChild('treeGrid') public treegrid: TreeGrid;
  public data: Observable<DataStateChangeEventArgs>;
  public pageSettings: PageSettingsModel;
  public dataManager: DataManager;
  treeGridData: Object;
  treeGridPageSize: number;
  parentData: any[];
  totalParentDataCount: number;
  editSettings: { allowEditing: boolean; allowAdding: boolean; allowDeleting: boolean; showDeleteConfirmDialog: boolean; mode: string; };
  toolbar: string[];
  constructor(
    private systemService: SystemService,
    private loaderService: LoaderService,
    private authService: AuthenticationService,
    private toastrService: ToastrService
  ) { }

  ngOnInit() {
    this.treeGridPageSize = 5;
    this.editSettings = { allowEditing: true, allowAdding: true, allowDeleting: true, showDeleteConfirmDialog: true, mode: 'Dialog' };
    this.toolbar = ['Add', 'Edit', 'Delete'];
    this.pageSettings = { pageSize: this.treeGridPageSize, pageSizeMode: 'Root' };

    this.dataManager = new DataManager({
      url: this.systemService.getApiUrl(),
      adaptor: new WebApiAdaptor,
      requestType: 'GET',
      crossDomain: true,
      headers: [{ Authorization: 'Bearer ' + this.authService.getIdToken() }]
    });

    this.dataManager.executeQuery(new Query().addParams('viewId', '')).then((e: any) => {
      this.parentData = e.result;
      this.totalParentDataCount = e.result.length;
      this.treeGridData = { result: this.parentData.slice(0, this.treeGridPageSize), count: this.totalParentDataCount };
    });
  }

  ngAfterViewInit() {
  }

  dataStateChange(state: any): void {
    if (state.requestType === 'expand') {
      //this.dataManager.executeQuery(new Query().where('parentId', 'equal', state.data.id)).then((e: any) => {
      this.dataManager.executeQuery(new Query().addParams('viewId', state.data.id)).then((e: any) => {
        state.childData = e.result;
        state.childDataBind();
      });

    } else {

      //this.dataManager.executeQuery(new Query().where('parentId', 'equal', null).skip(state.skip).take(state.take)).then((e: any) => {
      // this.dataManager.executeQuery(new Query().addParams('viewId', '').skip(state.skip).take(state.take)).then((e: any) => {
      //   //this.treeData = { result: e.result, count: 9 };
      //   this.treeData = { result: e.result, count: this.totalParentDataCount };
      // });
      console.log(this.parentData);
      console.log(state.skip, state.take);
      this.treeGridData = { result: this.parentData.slice(state.skip, state.skip + state.take), count: this.totalParentDataCount };
    }
  }

  dataSourceChanged(state: any): void {
    if (state.action === 'add') {
      // this.dataService.addRecord(this.kind, this.viewId, this.currentSystem.id, this.currentSystem.ancestry, state).subscribe(() => {
      //   this.treeGridData.notify('recordAdded', state);
      //   state.endEdit();
      // });
    }
    else if (state.action === 'edit') {
      // this.dataService.updateRecord(this.viewId, state).subscribe(() => {
      //   state.endEdit()
      // });
    }
    else if (state.requestType === 'delete') {
      // this.dataService.deleteRecord(this.viewId, state).subscribe(() =>
      //   state.endEdit());
    }
  }

  onActionFailure(e: any): void {
    console.log(e.error)
  }

  onTreeListExpanding(state: any): void {
  }

  onTreeListExpanded(state: any): void {
  }
}


